@@ -31,7 +31,7 @@ def index():
     {"candidate_id": "1234"}
     :return:
     """
-    print("Starting to notify candidates")
+    print(f"Starting to notify candidates {request.args}")
     recipients = ['anamadheyaashoka005@gmail.com', 'anamadheyaashoka003@gmail.com']
     candidate_id = request.args.get("candidate_id")
     jd_name = request.args.get("jd_name")
@@ -83,4 +83,4 @@ def home():
 
 
 def main():
-    app.run(host="0.0.0.0")
+    app.run(host="0.0.0.0", debug=True)
